clear all; clc;

% binary classs data generation
data_root_dir = '../data/gauss_2D_2C';
num_samp_train = 1000;	% for each class
num_samp_dev = 1000;	% for each class
num_samp_test = 200;	% for each class
num_samp = num_samp_train + num_samp_dev + num_samp_test;

%%%%%%%%%%%%%%%%%%%%%%%
% DATA GENERATION
%%%%%%%%%%%%%%%%%%%%%%%

% 1: ascii | 0: htk
out_format = 0;

mu1 = [1 1];
Sigma = [.5 .5; .5 .5]; R = chol(Sigma);
z1 = repmat(mu1,num_samp,1) + randn(num_samp,2)*R;

mu2 = [-1 -1];
z2 = repmat(mu2,num_samp,1) + randn(num_samp,2)*R;

%%%%%%%%%%%%%%%%%%%%%%%
% Print data for each partition
%%%%%%%%%%%%%%%%%%%%%%%

% PRINT TRAIN SET
dir_train = [data_root_dir '/train'];
system(['mkdir -p ' dir_train]);
for i=1:num_samp_train
  % class 1
  fbname_str1 = sprintf('%04.0f',i);
  fbname_str = ['C1_' fbname_str1];
  %disp(fbname_str);
  cur_data = z1(i,:);
  if     out_format == 1
    save([dir_train '/' fbname_str '.ascii'],'cur_data','-ascii');
  elseif out_format == 0
    writehtk([dir_train '/' fbname_str '.htk'],cur_data,1,9); % save in HTK format
  else
    error('wrong output format flag');
  end

  % class 2
  fbname_str1 = sprintf('%04.0f',i);
  fbname_str = ['C2_' fbname_str1];
  %disp(fbname_str);
  cur_data = z2(i,:);
  if     out_format == 1
    save([dir_train '/' fbname_str '.ascii'],'cur_data','-ascii');
  elseif out_format == 0
    writehtk([dir_train '/' fbname_str '.htk'],cur_data,1,9); % save in HTK format
  else
    error('wrong output format flag');
  end
end

% PRINT DEV SET
dir_dev = [data_root_dir '/dev'];
system(['mkdir -p ' dir_dev]);
for i=(num_samp_train+1):(num_samp_train + num_samp_dev)
  % class 1
  fbname_str1 = sprintf('%04.0f',i);
  fbname_str = ['C1_' fbname_str1];
  %disp(fbname_str);
  cur_data = z1(i,:);
  if     out_format == 1
    save([dir_dev '/' fbname_str '.ascii'],'cur_data','-ascii');
  elseif out_format == 0
    writehtk([dir_dev '/' fbname_str '.htk'],cur_data,1,9); % save in HTK format
  else
    error('wrong output format flag');
  end

  % class 2
  fbname_str1 = sprintf('%04.0f',i);
  fbname_str = ['C2_' fbname_str1];
  %disp(fbname_str);
  cur_data = z2(i,:);
  if     out_format == 1
    save([dir_dev '/' fbname_str '.ascii'],'cur_data','-ascii');
  elseif out_format == 0
    writehtk([dir_dev '/' fbname_str '.htk'],cur_data,1,9); % save in HTK format
  else
    error('wrong output format flag');
  end
end


% PRINT TEST SET
dir_test = [data_root_dir '/test'];
system(['mkdir -p ' dir_test]);
for i=(num_samp_train+num_samp_dev+1):num_samp
  % class 1
  fbname_str1 = sprintf('%04.0f',i);
  fbname_str = ['C1_' fbname_str1];
  %disp(fbname_str);
  cur_data = z1(i,:);
  if     out_format == 1
    save([dir_test '/' fbname_str '.ascii'],'cur_data','-ascii');
  elseif out_format == 0
    writehtk([dir_test '/' fbname_str '.htk'],cur_data,1,9); % save in HTK format
  else
    error('wrong output format flag');
  end

  % class 2
  fbname_str1 = sprintf('%04.0f',i);
  fbname_str = ['C2_' fbname_str1];
  %disp(fbname_str);
  cur_data = z2(i,:);
  if     out_format == 1
    save([dir_test '/' fbname_str '.ascii'],'cur_data','-ascii');
  elseif out_format == 0
    writehtk([dir_test '/' fbname_str '.htk'],cur_data,1,9); % save in HTK format
  else
    error('wrong output format flag');
  end
end



%%%%%%%%%%%%%%%%%%%%%%%
% LABEL GENERATION
%%%%%%%%%%%%%%%%%%%%%%%

list_par = {'train';'dev';'test'};

for iPar = 1:length(list_par)
  fw = fopen([data_root_dir '/' list_par{iPar} '/label'],'wt');
  list_file = dir([data_root_dir '/' list_par{iPar} '/C*']);
  for iFile = 1:length(list_file)
    fbname = list_file(iFile).name(1:end-4);
    lab = str2num(fbname(2))-1;
    fprintf(fw,'%s %d\n', fbname, lab);
  end
  fclose(fw);
end




